'''
NOTE: vandal package runs on top of the duality package, in order to see more about the actual code visit the duality package repositories at:
	https://github.com/dkundih/duality
	https://pypi.org/project/duality

This is a connection to the main folder of the vandal package.

AVAILABLE MODULES IN THE PACKAGE:
	HUB
	---
	vandal.hub is a hub of data manipulation tools.
		print(help(vandal.hub)) in order to see available features.
	MONTECARLO
	---
	vandal.MonteCarlo is a module for performing the Monte Carlo simulation over the defined data with a lot of useful features.
		print(help(vandal.MonteCarlo)) in order to see available features.
	EOQ
	---
	vandal.EOQ is a module for finding an Economic order quantity over the defined data with a lot of useful features.
		print(help(vandal.EOQ)) in order to see available features.

'''

#imports essential functions from the duality package.
from duality import EOQ
from duality.hub import hub
from duality.hub.hub import *
from duality import MonteCarlo

#imports meta data from the vandal package.
from vandal.misc._meta import (
	__author__,
	__copyright__,
	__credits__,
	__license__,
	__version__,
	__documentation__,
	__contact__,
	__donate__
)


# encoding: utf-8
'''
This module contains the meta-data of the package.
'''

__author__ = 'David Kundih'
__copyright__ = 'Copyright © 2021- David Kundih'
__credits__ = [
	'dkundih <https://github.com/dkundih>',

]
__license__ = 'Copyright © 2021- David Kundih. All rights reserved. Licensed under the Apache License, Version 2.0 | For more details about the license and terms of use visit the official duality documentation linked at https://github.com/dkundih/duality and https://pypi.org/project/duality'
__version__ = '2.2.6'
__documentation__ = 'https://github.com/dkundih/duality | https://pypi.org/project/duality'
__contact__ = 'dakundih@unin.hr | kundihdavid@gmail.com'
__donate__ = 'https://patreon.com/dkundih | https://buymeacoffee.com/dkundih'

#general setup confirmation.
def main():
    print('Setup successful.')

if __name__ == '__main__':
        main()